Index: apps/app_meetme.c
===================================================================
--- apps/app_meetme.c	(revision 96691)
+++ apps/app_meetme.c	(working copy)
@@ -5514,6 +5514,44 @@
 	return res;
 }
 
+
+static int acf_meetme_lock(struct ast_channel *chan, const char *cmd, char *args, char *buf, size_t len)
+{
+	struct ast_conference *conf;
+	int locked = 0;
+
+	if (ast_strlen_zero(args)) {
+		ast_log(LOG_WARNING, "Syntax: MEETME_LOCK(<conf>) - missing argument!\n");
+		return -1;
+	}
+
+	AST_LIST_LOCK(&confs);
+	AST_LIST_TRAVERSE(&confs, conf, list) {
+	if (!strcmp(args, conf->confno)) {
+			if ( conf->locked) {
+				locked = 1;
+			}
+			break;
+		}
+	}
+	AST_LIST_UNLOCK(&confs);
+
+	ast_copy_string(buf, locked? "1": "0", len);
+	return 0;
+}
+
+
+static struct ast_custom_function meetme_lock_acf = {
+	.name = "MEETME_LOCK",
+	.synopsis = "Tell if a meetme conference is locked or not",
+	.desc =
+"Returns a boolean of whether the corresponding conference is locked\n" 
+"Returns 1 if locked, 0 otherwise\n",
+	.syntax = "MEETME_LOCK(<conf>)",
+	.read = acf_meetme_lock,
+};
+
+
 static int load_config(int reload)
 {
 	load_config_meetme();
@@ -5547,6 +5585,8 @@
 	ast_devstate_prov_del("SLA");
 	
 	sla_destroy();
+	
+	res |= ast_custom_function_unregister(&meetme_lock_acf);
 
 	return res;
 }
@@ -5576,6 +5616,8 @@
 	res |= ast_devstate_prov_add("Meetme", meetmestate);
 	res |= ast_devstate_prov_add("SLA", sla_state);
 
+	res |= ast_custom_function_register(&meetme_lock_acf);
+
 	return res;
 }
 
